#
# spec file for package python-appdirs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# in order to avoid rewriting for subpackage generator
%define mypython python
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-appdirs
Version:        1.4.4
Release:        5.1
Summary:        A small Python module for determining platform-specific dirs
License:        MIT
URL:            https://github.com/ActiveState/appdirs
Source:         https://files.pythonhosted.org/packages/source/a/appdirs/appdirs-%{version}.tar.gz
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# work around boo#1186870
Provides:       %{mypython}%{python_version}dist(appdirs) = %{version}
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
Provides:       %{mypython}3dist(appdirs) = %{version}
%endif
%python_subpackages

%description
``appdirs`` will
help you choose an appropriate:

- user data dir (``user_data_dir``)
- user cache dir (``user_cache_dir``)
- site data dir (``site_data_dir``)
- user log dir (``user_log_dir``)

%prep
%setup -q -n appdirs-%{version}

# strip shebang
sed -r -i '1s/^#!.*$//' appdirs.py

%build
%python_build

%install
%python_install
%python_expand fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst README.rst
%pycache_only %{python_sitelib}/__pycache__/*
%{python_sitelib}/appdirs.py*
%{python_sitelib}/appdirs-%{version}-py%{python_version}.egg-info

%changelog
* Thu Aug 17 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add setuptools build requirement for building, distutils is not
  available anymore since python 3.12
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Jun 17 2021 Ben Greiner <code@bnavigator.de>
- Add Provides: for python*dist(appdirs): work around boo#1186870
* Tue Aug 18 2020 Matej Cepl <mcepl@suse.com>
- We can finally use %%pyunittest macro
* Tue Jun  2 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.4.4:
  - [PR #92] Don't import appdirs from setup.py
  Project officially classified as Stable which is important
  for inclusion in other distros such as ActivePython.
  First of several incremental releases to catch up on maintenance.
* Tue Nov  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Mon Sep 10 2018 Matěj Cepl <mcepl@suse.com>
- Revert removal of the code fixing egginfo (boo#1107798)
- Actually we don't need remove-setuptools-dependency.patch,
  when we don't run python setup.py test anymore. So, remove it.
* Tue Sep  4 2018 Matěj Cepl <mcepl@suse.com>
- Clean SPEC and remove circular dependency on python-setuptools
  (Add remove-setuptools-dependency.patch patch to do this)
* Fri Aug 17 2018 tchvatal@suse.com
- Use setuptools normally
- Run tests
* Tue Aug 14 2018 ms@suse.com
- Submission to SUSE:SLE-12-SP3:Update:PubClouds
  This commit tracks the submission for fate#326575
  and bsc#1103542
* Tue Aug  8 2017 tbechtold@suse.com
- update to 1.4.3:
  - [PR #76] Python 3.6 invalid escape sequence deprecation fixes
  - Fix for Python 3.6 support
  - [PR #84] Allow installing without setuptools
  - [PR #86] Fix string delimiters in setup.py description
  - Add Python 3.6 support
- drop desetuptoolize.patch . no longer needed.
* Thu Feb 23 2017 jmatejek@suse.com
- update for single-spec
- desetuptoolize.patch : switch from setuptools to distutils.core
  for installation, as this is now a setuptools dependency
- ensure egg-info is a directory (distutils would install it as file)
- update to 1.4.1
  * [issue 55] make appname optional
* Wed Jun  3 2015 tbechtold@suse.com
- update to 1.4.0:
  - [PR #42] AppAuthor is now optional on Windows
  - [issue 41] Support Jython on Windows, Mac, and Unix-like platforms. Windows
    support requires `JNA <https://github.com/twall/jna>`_.
  - [PR #44] Fix incorrect behaviour of the site_config_dir method
  - [Unix, issue 16] Conform to XDG standard, instead of breaking it for
    everybody
  - [Unix] Removes gratuitous case mangling of the case, since \*nix-es are
    usually case sensitive, so mangling is not wise
  - [Unix] Fixes the uterly wrong behaviour in ``site_data_dir``, return result
    based on XDG_DATA_DIRS and make room for respecting the standard which
    specifies XDG_DATA_DIRS is a multiple-value variable
  - [Issue 6] Add ``*_config_dir`` which are distinct on nix-es, according to
    XDG specs; on Windows and Mac return the corresponding ``*_data_dir``
- Remove unzip as BuildRequires. tar.gz file now provided and used
* Mon Mar 24 2014 toddrme2178@gmail.com
- Initial version
